@@ -991,7 +991,7 @@ HEADER
                 $code = '(Sidef::Types::Number::Number::MONE)';
             }
             else {
-                $code = $self->make_constant($ref, 'new', "Number$refaddr", "'" . $obj->_get_frac . "'");
+                $code = $self->make_constant($ref, '_set_str', "Number$refaddr", "'" . $obj->_get_frac . "'");
             }
         }
         elsif ($ref eq 'Sidef::Types::Number::Inf') {
@@ -1051,7 +1051,7 @@ HEADER
             # my $block = $self->deparse_expr({self => $obj->{block}});
 
             my $vars;
-            if (exists($obj->{block}{init_vars}) and @{$obj->{block}{init_vars}{vars}}) {
+            if (@{$obj->{block}{init_vars}{vars}}) {
                 $vars = $self->_dump_sub_init_vars(@{$obj->{block}{init_vars}{vars}});
             }
 
