@@ -1,7 +1,6 @@
 package Sidef::Deparse::Sidef {
 
     use 5.014;
-    our @ISA = qw(Sidef);
     use Scalar::Util qw(refaddr reftype);
 
     my %addr;
@@ -22,6 +21,7 @@ package Sidef::Deparse::Sidef {
                   Sidef::DataTypes::Bool::Bool            Bool
                   Sidef::DataTypes::Array::Array          Array
                   Sidef::DataTypes::Array::Pair           Pair
+                  Sidef::DataTypes::Array::Enumerator     Enumerator
                   Sidef::DataTypes::Array::MultiArray     MultiArray
                   Sidef::DataTypes::Hash::Hash            Hash
                   Sidef::DataTypes::Regex::Regex          Regex
@@ -40,7 +40,8 @@ package Sidef::Deparse::Sidef {
                   Sidef::DataTypes::Glob::File            File
                   Sidef::DataTypes::Object::Object        Object
                   Sidef::DataTypes::Sidef::Sidef          Sidef
-                  Sidef::DataTypes::Variable::LazyMethod  LazyMethod
+                  Sidef::DataTypes::Object::Lazy          Lazy
+                  Sidef::DataTypes::Object::LazyMethod    LazyMethod
 
                   Sidef::Math::Math                       Math
                   Sidef::Meta::Glob::ARGF                 ARGF
