@@ -1814,22 +1814,8 @@ package Sidef::Types::Array::Array {
 
     sub copy {
         my ($self) = @_;
-
-        my @array;
-        my $sub;
-        foreach my $item (@{$self}) {
-            if (ref($item) and defined($sub = UNIVERSAL::can($item, 'copy'))) {
-                CORE::push(@array, $sub->($item));
-            }
-            else {
-                CORE::push(@array, $item);
-            }
-        }
-
-        $self->new(\@array);
-
-        #state $x = require Storable;
-        #Storable::dclone($self);           # this is buggy
+        state $x = warn "[WARN] Array.copy() is deprecated: use .clone() or .dclone() instead!\n";
+        $self->dclone;
     }
 
     sub delete_first {
@@ -1927,18 +1913,36 @@ package Sidef::Types::Array::Array {
     sub to_list { @{$_[0]} }
 
     sub dump {
-        my ($self) = @_;
 
-        Sidef::Types::String::String->new(
-            '[' . CORE::join(
-                ', ',
-                map {
-                    my $item = defined($self->[$_]) ? $self->[$_] : 'nil';
-                    ref($item) && defined(UNIVERSAL::can($item, 'dump')) ? $item->dump() : $item;
-                  } 0 .. $#{$self}
-              )
-              . ']'
-        );
+        my %addr;    # keeps track of dumped objects
+
+        my $sub = sub {
+            my ($obj) = @_;
+
+            my $refaddr = Scalar::Util::refaddr($obj);
+
+            exists($addr{$refaddr})
+              and return $addr{$refaddr};
+
+            my $str = Sidef::Types::String::String->new("Array(#`($refaddr)...)");
+            $addr{$refaddr} = $str;
+
+            $$str = (
+                '[' . CORE::join(
+                    ', ',
+                    map {
+                        my $item = defined($obj->[$_]) ? $obj->[$_] : 'nil';
+                        ref($item) && defined(UNIVERSAL::can($item, 'dump')) ? $item->dump() : $item;
+                      } 0 .. $#{$obj}
+                  )
+                  . ']'
+            );
+
+            $str;
+        };
+
+        local *Sidef::Types::Array::Array::dump = $sub;
+        $sub->($_[0]);
     }
 
     sub to_s {
