@@ -104,13 +104,19 @@ package Sidef::Types::Regex::Match {
 
     sub join {
         my ($self, $sep) = @_;
-        Sidef::Types::String::String->new(CORE::join($sep->get_value, @{$self->{captures}}));
+        Sidef::Types::String::String->new(CORE::join("$sep", @{$self->{captures}}));
     }
 
     sub to_s {
         my ($self) = @_;
         Sidef::Types::String::String->new(CORE::join(' ', @{$self->{captures}}));
     }
+
+    sub dump {
+        my ($self) = @_;
+        my $re = $self->{self}->dump;
+        Sidef::Types::String::String->new("(${Sidef::Types::String::String->new($self->{obj})->dump} =~ $re)");
+    }
 };
 
 1
